<?php
/*
  Plugin Name: Envelope From
  Plugin URI:
  Description: メール送信の際にEnvelope Fromを設定する
  Version: 0.9
  Author: sainoa
  License: public domain
*/


add_action('admin_menu', 'evfr_menu');

function evfr_menu() {
    add_submenu_page('options-general.php', 'Envelope From', 'Envelope From',
			'administrator', plugin_basename( __FILE__ ), 'evfr_set_adrs');
}


function evfr_set_adrs() {
    if (isset($_POST['evfr_mail_adrs'])) {
	check_admin_referer('evfr_chk');
	update_option('evfr_mail_adrs', trim($_POST['evfr_mail_adrs']));

	if (isset($_POST['test']) && isset($_POST['evfr_test_adrs'])) {
	    $evfr_test_adrs = trim($_POST['evfr_test_adrs']);
	    update_option('evfr_test_adrs', $evfr_test_adrs);

	    if ($evfr_test_adrs != "") {
		wp_mail($evfr_test_adrs, "test from plugin", "just test");
		$msg = "保存とテスト送信を行いました";
	    }
	    else {
		$msg = "保存しました（テスト送信先が空の送信していません）";
	    }
	}
	else {
	    $msg = "保存しました";
	}

	echo("<div class='updated fade'><p><strong>" . $msg . "</strong></p></div>");
    }
    
    $evfr_mail_adrs = trim(get_option('evfr_mail_adrs', ""));
    $evfr_test_adrs = trim(get_option('evfr_test_adrs', ""));

    $evfr_domain_name = str_ireplace("www.", "", $_SERVER["HTTP_HOST"]);
    
    echo <<< EOT_1
<div class="wrap">
<h1>メール送信時のEnvelope Fromの設定</h1>
<p>
  実在するメールアドレスを指定します。一般的にはドメインはこのサイトと一致させます。<br>
  【例】 adimn@{$evfr_domain_name}
</p>

<form action="" method='post' id="my-submenu-form">
    <p>
      Envelope From：
      <input type="text" name="evfr_mail_adrs" value="{$evfr_mail_adrs}"/>
    </p>
EOT_1;

    wp_nonce_field('evfr_chk');

    echo <<< EOT_2
    <p>※アドレスの正当性はチェックしません。ご注意ください。</p>
    <p><input type='submit' name='setting' value='設定' class='button button-primary button-large'></p>
    <p>
      テスト送信先メールアドレス：
      <input type="text" name="evfr_test_adrs" value="{$evfr_test_adrs}"/>
    </p>
    <p><input type='submit' name='test' value='設定 & テスト送信' class='button button-primary button-large'></p>
</form>
</div>
EOT_2;
}


add_action('phpmailer_init',
    function($phpmailer) {
	$evfr_mail_adrs = trim(get_option('evfr_mail_adrs', ""));

	if ($evfr_mail_adrs != "") {
	    $phpmailer->SMTPKeepAlive = true;
	    $phpmailer->Sender = $evfr_mail_adrs;
	}
    }
);


add_filter('plugin_action_links_' . plugin_basename( __FILE__ ), 'evfr_add_action_links');


function evfr_add_action_links($actions) {
    $url = admin_url('options-general.php?page=' . plugin_basename( __FILE__ ));
    $url = '<a href="' . esc_url($url) . '">' . __( 'Settings' ) . '</a>';
    array_unshift($actions, $url);

    return $actions;
}

/* vi: set tabstop=8 shiftwidth=4 encoding=utf-8 */
